==> aspose-total-java-23.11.0.tar.gz: aspose-total-java-23.11.0/README.md <==
[Home](https://www.aspose.com/) | [Product Page](https://products.aspose.com/total/python-java) | [Docs](https://docs.aspose.com/total/pythonjava/) | [Demos](https://products.aspose.app/total/family) | [Examples](https://aspose.github.io/) | [Download](https://downloads.aspose.com/total/pythonjava) | [Blog](https://blog.aspose.com/category/total/) | [Releases](https://releases.aspose.com/) | [Free Support](https://forum.aspose.com/c/total/7) | [Temporary License](https://purchase.aspose.com/temporary-license)

# [Aspose.BarCode for Python via Java](https://pypi.org/project/aspose-barcode-for-python-via-java/23.11/) (23.11.0)

Aspose.BarCode for Python via Java is an on-premise API that can generate, read, & recognize barcodes without any 3rd party software. Create multiple types of barcodes (1D, 2D, Postal) with support for several barcode symbologies (numeric, alpha-numeric, 2D). Set barcode code text and configure its contents, formatting, & appearance. Support for checksum and supplement data is available. Customize barcode image color, back color, and bar color, bar height, and rotation etc. Anti-Aliasing for barcode images is also supported.

## Supported Barcode Input/Output Formats

- **Image:** JPEG, PNG, BMP, GIF

```python
pip install aspose-barcode-for-python-via-java==23.11
```

# [Aspose.Cells for Python via Java](https://pypi.org/project/aspose-cells/23.11.0/) (23.11.0)

Aspose.Cells for Python via Java is a fast & reliable Python class library to incorporate spreadhseet processing capabilities into your Python programs. Create, process, render, & convert Microsoft Excel&reg; and OpenOffice&reg; spreadsheets. Work with spreadsheet, worksheet, & workbook tables, images, charts, pivot charts, formula, formatting, page setup, & conditional formatting. It offers an easy solution to automate Excel&reg; reports using python.

## Supported Excel&reg; Input/Output Formats

- **Microsoft Excel&reg;:** XLS, XLSX, XLSB, XLTX, XLTM, XLSM, XML
- **OpenOffice&reg;:** ODS
- **Text:** CSV, TSV, TXT
- **Web:** HTML, MHTML

## Supported Excel&reg; Output Formats

- **Fixed Layout:** PDF, PDF/A, XPS
- **Images:** JPEG, PNG, BMP, SVG, EMF

```python
pip install aspose-cells==23.11.0
```

# [Aspose.Diagram for Python via Java](https://pypi.org/project/aspose-diagram/23.11.0/) (23.11.0)

Aspose.Diagram for Python via Java is a class library that enables your applications to work with, process, and manipulate Microsoft Visio&reg; drawings from within your programs without the need to install any 3rd party software. Create various types of Visio&reg; diagrams from scratch, read various Visio&reg; file formats, edit Visio document properties, and export Visio&reg; Shapes to various other file formats.

## Supported Diagram Input/Output Formats

- **Microsoft Visio:** VSDX, VDX, VSX, VTX, VSSX, VSTX, VSDM, VSSM, VSTM

## Supported Diagram Input Only Formats

- **Microsoft Visio:** VDW, VSD, VSS, VST

## Supported Diagram Output Only Formats

- **Fixed Layout:** PDF, XPS
- **Images:** JPEG, PNG, BMP, TIFF, SVG, EMF
- **Others:** XAML

```python
pip install aspose-diagram==23.11.0
```

# [Aspose.PDF for Python via Java](https://pypi.org/project/aspose-pdf-for-python-via-java/23.10/) (23.10.0)

Aspose.PDF for Python via Java is a robust and reliable pdf generation and recognition component, written in Python and Java. It allows developers to quickly and easily add pdf creation and scanning functionality to their Python applications.

## Supported Input/Output PDF Formats

- **Microsoft Office&reg;:** XLS, XLSX
- **Web:** HTML
- **eBooks:** EPUB
- **Other:** TEX, XML, SVG, MD, MHT

## Supported Read PDF Formats

- **Fixed Layout:** PDF, XPS
- **Microsoft Office&reg;:** CGM
- **Others:** PS, PCL, CGM, XSLFO/XML

## Save PDF Documents As

- **Microsoft Office:** DOC, DOCX, PPTX
- **Images:** JPEG, PNG, BMP, TIFF, GIF
- **Other:** MobiXML, XML, TEXT

```python
pip install aspose-pdf-for-python-via-java==23.10
```

# Aspose.Total for Python via Java Features

- Read Miscrosoft Excel&reg; & OpenOffice&reg; Spreadsheets via Python
- Convert Excel&reg; & ODS formats to PDF, XPS, images, & EMF
- Work with tables, rows, columns, cells, charts, conditional formatting
- Create Microsoft Visio&reg; diagrams & flowcharts
- Export Visio&reg; diagrams to PDF, XPS, Images, & XAML formats
- Generate & recognize various types of 1D, 2D, & postal barcodes
- Set code text for barcode labels
- Support for popular barcode symbologies
- many many more.

[Home](https://www.aspose.com/) | [Product Page](https://products.aspose.com/total/python-java) | [Docs](https://docs.aspose.com/total/pythonjava/) | [Demos](https://products.aspose.app/total/family) | [Examples](https://aspose.github.io/) | [Download](https://downloads.aspose.com/total/pythonjava) | [Blog](https://blog.aspose.com/category/total/) | [Releases](https://releases.aspose.com/) | [Free Support](https://forum.aspose.com/c/total/7) | [Temporary License](https://purchase.aspose.com/temporary-license)

==> aspose-total-java-23.12.0.tar.gz: aspose-total-java-23.12.0/README.md <==
[Home](https://www.aspose.com/) | [Product Page](https://products.aspose.com/total/python-java) | [Docs](https://docs.aspose.com/total/pythonjava/) | [Demos](https://products.aspose.app/total/family) | [Examples](https://aspose.github.io/) | [Download](https://downloads.aspose.com/total/pythonjava) | [Blog](https://blog.aspose.com/category/total/) | [Releases](https://releases.aspose.com/) | [Free Support](https://forum.aspose.com/c/total/7) | [Temporary License](https://purchase.aspose.com/temporary-license)

# [Aspose.BarCode for Python via Java](https://releases.aspose.com/barcode/python-java/) (23.12.0)

Aspose.BarCode for Python via Java is an on-premise API that can generate, read, & recognize barcodes without any 3rd party software. Create multiple types of barcodes (1D, 2D, Postal) with support for several barcode symbologies (numeric, alpha-numeric, 2D). Set barcode code text and configure its contents, formatting, & appearance. Support for checksum and supplement data is available. Customize barcode image color, back color, and bar color, bar height, and rotation etc. Anti-Aliasing for barcode images is also supported.

## Supported Barcode Input/Output Formats

- **Image:** JPEG, PNG, BMP, GIF

```python
pip install aspose-barcode-for-python-via-java==23.12
```

# [Aspose.Cells for Python via Java](https://releases.aspose.com/cells/python-java/) (23.12.0)

Aspose.Cells for Python via Java is a fast & reliable Python class library to incorporate spreadhseet processing capabilities into your Python programs. Create, process, render, & convert Microsoft Excel&reg; and OpenOffice&reg; spreadsheets. Work with spreadsheet, worksheet, & workbook tables, images, charts, pivot charts, formula, formatting, page setup, & conditional formatting. It offers an easy solution to automate Excel&reg; reports using python.

## Supported Excel&reg; Input/Output Formats

- **Microsoft Excel&reg;:** XLS, XLSX, XLSB, XLTX, XLTM, XLSM, XML
- **OpenOffice&reg;:** ODS
- **Text:** CSV, TSV, TXT
- **Web:** HTML, MHTML

## Supported Excel&reg; Output Formats

- **Fixed Layout:** PDF, PDF/A, XPS
- **Images:** JPEG, PNG, BMP, SVG, EMF

```python
pip install aspose-cells==23.12.0
```

# [Aspose.Diagram for Python via Java](https://releases.aspose.com/diagram/python-java/) (23.12.0)

Aspose.Diagram for Python via Java is a class library that enables your applications to work with, process, and manipulate Microsoft Visio&reg; drawings from within your programs without the need to install any 3rd party software. Create various types of Visio&reg; diagrams from scratch, read various Visio&reg; file formats, edit Visio document properties, and export Visio&reg; Shapes to various other file formats.

## Supported Diagram Input/Output Formats

- **Microsoft Visio:** VSDX, VDX, VSX, VTX, VSSX, VSTX, VSDM, VSSM, VSTM

## Supported Diagram Input Only Formats

- **Microsoft Visio:** VDW, VSD, VSS, VST

## Supported Diagram Output Only Formats

- **Fixed Layout:** PDF, XPS
- **Images:** JPEG, PNG, BMP, TIFF, SVG, EMF
- **Others:** XAML

```python
pip install aspose-diagram==23.12.0
```

# [Aspose.PDF for Python via Java](https://releases.aspose.com/pdf/pythonjava/) (23.10.0)

Aspose.PDF for Python via Java is a robust and reliable pdf generation and recognition component, written in Python and Java. It allows developers to quickly and easily add pdf creation and scanning functionality to their Python applications.

## Supported Input/Output PDF Formats

- **Microsoft Office&reg;:** XLS, XLSX
- **Web:** HTML
- **eBooks:** EPUB
- **Other:** TEX, XML, SVG, MD, MHT

## Supported Read PDF Formats

- **Fixed Layout:** PDF, XPS
- **Microsoft Office&reg;:** CGM
- **Others:** PS, PCL, CGM, XSLFO/XML

## Save PDF Documents As

- **Microsoft Office:** DOC, DOCX, PPTX
- **Images:** JPEG, PNG, BMP, TIFF, GIF
- **Other:** MobiXML, XML, TEXT

```python
pip install aspose-pdf-for-python-via-java==23.10
```

# Aspose.Total for Python via Java Features

- Read Miscrosoft Excel&reg; & OpenOffice&reg; Spreadsheets via Python
- Convert Excel&reg; & ODS formats to PDF, XPS, images, & EMF
- Work with tables, rows, columns, cells, charts, conditional formatting
- Create Microsoft Visio&reg; diagrams & flowcharts
- Export Visio&reg; diagrams to PDF, XPS, Images, & XAML formats
- Generate & recognize various types of 1D, 2D, & postal barcodes
- Set code text for barcode labels
- Support for popular barcode symbologies
- many many more.

[Home](https://www.aspose.com/) | [Product Page](https://products.aspose.com/total/python-java) | [Docs](https://docs.aspose.com/total/pythonjava/) | [Demos](https://products.aspose.app/total/family) | [Examples](https://aspose.github.io/) | [Download](https://downloads.aspose.com/total/pythonjava) | [Blog](https://blog.aspose.com/category/total/) | [Releases](https://releases.aspose.com/) | [Free Support](https://forum.aspose.com/c/total/7) | [Temporary License](https://purchase.aspose.com/temporary-license)
